ardt.datasets.ml.TorchDatasetWrapper
====================================

.. currentmodule:: ardt.datasets.ml

.. autoclass:: TorchDatasetWrapper

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TorchDatasetWrapper.__init__
      ~TorchDatasetWrapper.generate
   
   

   
   
   